@@ -66,6 +66,9 @@ term_signal_caught = False
 
 univention.admin.modules.update()
 
+RE_NO_RESYNC = re.compile('^<NORESYNC(=.*?)?>;')
+
+
 try:
     univention.admin.handlers.disable_ad_restrictions(disable=False)
 except AttributeError:
@@ -581,8 +584,7 @@ class ucs(object):
     def list_rejected_ucs(self, filter_noresync=False):
         rejected = self._get_config_items('UCS rejected')
         if filter_noresync:
-            no_resync = re.compile('^<NORESYNC(=.*?)?>;')
-            return [(fn, dn) for (fn, dn) in rejected if no_resync.match(dn) is None]
+            return [(fn, dn) for (fn, dn) in rejected if RE_NO_RESYNC.match(dn) is None]
         return rejected
 
     def _list_rejected_ucs(self):
@@ -679,8 +681,8 @@ class ucs(object):
                     old_dn = old_dn.decode('utf-8')
         except IOError:
             return True  # file not found so there's nothing to sync
-        except (pickle.UnpicklingError, EOFError) as e:
-            message = 'file emtpy' if isinstance(e, EOFError) else e.message
+        except (pickle.UnpicklingError, EOFError) as exc:
+            message = 'file empty' if isinstance(exc, EOFError) else exc
             ud.debug(ud.LDAP, ud.ERROR, f'__sync_file_from_ucs: invalid pickle file {filename}: {message}')
             # ignore corrupted pickle file, but save as rejected to not try again
             self._save_rejected_ucs(filename, 'unknown', resync=False, reason='broken file')
@@ -986,8 +988,8 @@ class ucs(object):
                                 old_dn = old_dn.decode('utf-8')
                     except IOError:
                         continue  # file not found so there's nothing to sync
-                    except (pickle.UnpicklingError, EOFError) as e:
-                        message = 'file emtpy' if isinstance(e, EOFError) else e.message
+                    except (pickle.UnpicklingError, EOFError) as exc:
+                        message = 'file empty' if isinstance(exc, EOFError) else exc
                         ud.debug(ud.LDAP, ud.ERROR, f'poll_ucs: invalid pickle file {filename}: {message}')
                         # ignore corrupted pickle file, but save as rejected to not try again
                         self._save_rejected_ucs(filename, 'unknown', resync=False, reason='broken file')
